***************
Getting Started
***************

New to *PyMend*? Don't worry, you've found the perfect place to get started!


Installation
============

*PyMend* can be installed by running :code:`pip install pymend`. It requires Python 3.9+ to run.

If you can't wait for the latest *hotness* and want to install from GitHub, use:

:code:`pip install git+https://github.com/JanEricNitschke/pymend`

Basic usage
===========

To get started right away with sensible defaults:

.. code-block:: sh

    pymend {source_file}...


You can run *PyMend* as a package if running it as a script doesn't work:

.. code-block:: sh

    python -m pymend {source_file}...


Next steps
==========

Try out *PyMend*? Fantastic, you're ready for more.

Why not explore some more on using *PyMend* by reading
:ref:`Usage and Configuration: The basics<The basics>`.

Alternatively, you can check out the
:ref:`Introducing *PyMend* to your project<Introducing Pymend to your project>`
guide.
